| Title: | Get Insights on 'lubridate' Operations |
|---|---|
| Description: | Provides a set of tools designed to enhance transparency and understanding of date-time manipulation functions from the 'lubridate' package. It provides detailed feedback about the operations performed by 'lubridate' functions, allowing users to better comprehend and debug their code. These insights serve as both a learning tool for newcomers and a debugging aid for programmers working with date-time data. |
| Authors: | Mikael Moise [aut, cre, cph] |
| Maintainer: | Mikael Moise <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.3.0 |
| Built: | 2026-05-12 06:24:00 UTC |
| Source: | https://github.com/arrismo/lubrilog |
Wrapper function around lubridate::dmy that gives feedback about parsed variable
dmy(.data, ...)dmy(.data, ...)
.data |
see dmy |
... |
see dmy |
see dmy
Wrapper function around lubridate::dmy_h that gives feedback about parsed variable
dmy_h(.data, ...)dmy_h(.data, ...)
.data |
see dmy_h |
... |
see dmy_h |
see dmy_h
Wrapper function around lubridate::dmy_hms that gives feedback about parsed variable
dmy_hms(.data, ...)dmy_hms(.data, ...)
.data |
see dmy_hms |
... |
see dmy_hms |
see dmy_hms
A subset of data from steam game data
gamesgames
A data frame with 13,357 rows and 7 columns:
Game ID
Game Name
Data the game was released
Boolean Variable indicating if the game can be played on windows os
Boolean Variable indicating if the game can be played on linux
Boolean Variable indicating if the game can be played on mac os
Initial Price at release date
Wrapper function around lubridate::hm that gives feedback about parsed variable
hm(.data, ...)hm(.data, ...)
.data |
see hm |
... |
see hm |
see hm
Wrapper function around lubridate::hms that gives feedback about parsed variable
hms(.data, ...)hms(.data, ...)
.data |
see hms |
... |
see hms |
see hms
Wrapper function around lubridate::mdy that gives feedback about parsed variable
mdy(.data, ...)mdy(.data, ...)
.data |
see mdy |
... |
see mdy |
see mdy
Wrapper function around lubridate::mdy_h that gives feedback about parsed variable
mdy_h(.data, ...)mdy_h(.data, ...)
.data |
see mdy_h |
... |
see mdy_h |
see mdy_h
Wrapper function around lubridate::mdy_hms that gives feedback about parsed variable
mdy_hms(.data, ...)mdy_hms(.data, ...)
.data |
see mdy_hms |
... |
see mdy_hms |
see mdy_hms
Wrapper function around lubridate::ms that gives feedback about parsed variable
ms(.data, ...)ms(.data, ...)
.data |
see ms |
... |
see ms |
see ms
Wrapper function around lubridate::my that gives feedback about parsed variable
my(.data, ...)my(.data, ...)
.data |
see my |
... |
see my |
see my
Wrapper function around lubridate::myd that gives feedback about parsed variable
myd(.data, ...)myd(.data, ...)
.data |
see myd |
... |
see myd |
see myd
Wrapper function around lubridate::ydm that gives feedback about parsed variable
ydm(.data, ...)ydm(.data, ...)
.data |
see ydm |
... |
see ydm |
see ydm
Wrapper function around lubridate::ydm_h that gives feedback about parsed variable
ydm_h(.data, ...)ydm_h(.data, ...)
.data |
see ydm_h |
... |
see ydm_h |
see ydm_h
Wrapper function around lubridate::ydm_hms that gives feedback about parsed variable
ydm_hms(.data, ...)ydm_hms(.data, ...)
.data |
see ydm_hms |
... |
see ydm_hms |
see ydm_hms
Wrapper function around lubridate::year that gives feedback about parsed variable
year(.data, ...)year(.data, ...)
.data |
see year |
... |
see year |
see year
Wrapper function around lubridate::ym that gives feedback about parsed variable
ym(.data, ...)ym(.data, ...)
.data |
see ym |
... |
see ym |
see ym
Wrapper function around lubridate::ymd that gives feedback about parsed variable
ymd(.data, ...)ymd(.data, ...)
.data |
see ymd |
... |
see ymd |
see ymd
Wrapper function around lubridate::ymd_h that gives feedback about parsed variable
ymd_h(.data, ...)ymd_h(.data, ...)
.data |
see ymd_h |
... |
see ymd_h |
see ymd_h
Wrapper function around lubridate::ymd_hms that gives feedback about parsed variable
ymd_hms(.data, ...)ymd_hms(.data, ...)
.data |
see ymd_hms |
... |
see ymd_hms |
see ymd_hms
Wrapper function around lubridate::yq that gives feedback about parsed variable
yq(.data, ...)yq(.data, ...)
.data |
see yq |
... |
see yq |
see yq